/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "winceqtversionfactory.h"
#include "winceqtversion.h"
#include "qtsupportconstants.h"
#include "profilereader.h"

#include <QFileInfo>

using namespace QtSupport;
using namespace QtSupport::Internal;

WinCeQtVersionFactory::WinCeQtVersionFactory(QObject *parent)
    : QtVersionFactory(parent)
{

}

WinCeQtVersionFactory::~WinCeQtVersionFactory()
{

}

bool WinCeQtVersionFactory::canRestore(const QString &type)
{
    return type == QLatin1String(Constants::WINCEQT);
}

BaseQtVersion *WinCeQtVersionFactory::restore(const QString &type, const QVariantMap &data)
{
    if (!canRestore(type))
        return 0;
    WinCeQtVersion *v = new WinCeQtVersion;
    v->fromMap(data);
    return v;
}

int WinCeQtVersionFactory::priority() const
{
    return 50;
}

BaseQtVersion *WinCeQtVersionFactory::create(const Utils::FileName &qmakePath, ProFileEvaluator *evaluator, bool isAutoDetected, const QString &autoDetectionSource)
{
    QFileInfo fi = qmakePath.toFileInfo();
    if (!fi.exists() || !fi.isExecutable() || !fi.isFile())
        return 0;

    QString ce_sdk = evaluator->values(QLatin1String("CE_SDK")).join(QLatin1Char(' '));
    QString ce_arch = evaluator->value(QLatin1String("CE_ARCH"));

    if (!ce_sdk.isEmpty() && !ce_arch.isEmpty())
        return new WinCeQtVersion(qmakePath, ce_arch, isAutoDetected, autoDetectionSource);

    return 0;
}
